==> geant4.9.4.p03.tar.gz: geant4.9.4.p03/source/run/src/G4VPersistencyManager.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id: G4VPersistencyManager.cc,v 1.5 2006-06-29 21:14:02 gunter Exp $
// GEANT4 tag $Name: not supported by cvs2svn $
//

#include "G4VPersistencyManager.hh"

G4VPersistencyManager* G4VPersistencyManager::fPersistencyManager = 0;

G4VPersistencyManager* G4VPersistencyManager::GetPersistencyManager()
{
  return fPersistencyManager;
}

G4VPersistencyManager::G4VPersistencyManager()
{
  fPersistencyManager = this;
}

G4VPersistencyManager::~G4VPersistencyManager()
{
  fPersistencyManager = 0;
}

==> geant4.10.01.p03.tar.gz: geant4.10.01.p03/source/run/src/G4VPersistencyManager.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id: G4VPersistencyManager.cc 66892 2013-01-17 10:57:59Z gunter $
//

#include "G4VPersistencyManager.hh"

G4ThreadLocal G4VPersistencyManager* G4VPersistencyManager::fPersistencyManager = 0;

G4VPersistencyManager* G4VPersistencyManager::GetPersistencyManager()
{
  return fPersistencyManager;
}

G4VPersistencyManager::G4VPersistencyManager()
{
  fPersistencyManager = this;
}

G4VPersistencyManager::~G4VPersistencyManager()
{
  fPersistencyManager = 0;
}
